@@ -199,7 +199,7 @@ class ReportClass(FactsheetReportMixin, ReportMixin):
         return template.render(context)
 
     @classmethod
-    def generate_file(cls, context):
+    def generate_file(cls, context):  # noqa: C901
         debug = False
         # Product Data
         # Main Feature table as dictionary
@@ -446,7 +446,7 @@ class ReportClass(FactsheetReportMixin, ReportMixin):
         # Price Timeseries Chart
         elements.append(
             get_timeseries_chart(
-                data=[list(zip(prices.index, prices.net_value))],
+                data=[list(zip(prices.index, prices.net_value, strict=False))],
                 width=CONTENT_WIDTH_PAGE1_LEFT - CONTENT_OFFSET,
                 height=4.34 * cm,
                 color=c_product,
@@ -467,7 +467,7 @@ class ReportClass(FactsheetReportMixin, ReportMixin):
                     "<strong>Top 3 Contributors</strong>",
                     "<strong>Bottom 3 Contributors</strong>",
                 ],
-                data=list(zip(top_3_holdings, top_3_contributors, bottom_3_contributors)),
+                data=list(zip(top_3_holdings, top_3_contributors, bottom_3_contributors, strict=False)),
                 width=CONTENT_WIDTH_PAGE1_LEFT,
                 header_row_height=0.85 * cm,
                 data_row_height=0.39 * cm,
@@ -636,7 +636,7 @@ class ReportClass(FactsheetReportMixin, ReportMixin):
 
             data = list()
             categories = list()
-            for index, row in enumerate(df.itertuples()):
+            for row in df.itertuples():
                 data.append(row.weighting * 100)
                 categories.append(f"{row.aggregated_title} ({row.weighting * 100:.1f}%)")
 
