@@ -4,7 +4,7 @@ from reportlab.lib.colors import transparent
 
 
 class CustomLegend(Legend):
-    def _defaultSwatch(self, x, thisy, dx, dy, fillColor, strokeWidth, strokeColor):
+    def _defaultSwatch(self, x, thisy, dx, dy, fillColor, strokeWidth, strokeColor):  # noqa: N803, N802
         return Circle(
             x,
             thisy + dx / 2,
