@@ -29,6 +29,7 @@ from reportlab.platypus import (
 from reportlab.platypus.flowables import KeepTogether, TopPadder
 from reportlab.platypus.frames import Frame
 from svglib.svglib import svg2rlg
+
 from wbreport.models import ReportAsset
 from wbreport.pdf.charts.pie import (
     get_pie_chart_horizontal,
@@ -42,7 +43,7 @@ from wbreport.pdf.tables.aggregated_tables import get_simple_aggregated_table
 from wbreport.pdf.tables.data_tables import get_simple_data_table
 
 
-def generate_report(context):
+def generate_report(context):  # noqa: C901
     debug = False
 
     main_features_dict = context["information_table"]["Main Features"]
@@ -133,7 +134,7 @@ def generate_report(context):
     s_table_medium = ParagraphStyle(name="s_table_medium", parent=s_table_base, fontSize=9, leading=8)
     s_table_medium_leading = ParagraphStyle(name="s_table_medium_leading", parent=s_table_medium, leading=13.9)
     s_table_large = ParagraphStyle(name="s_table_large", parent=s_table_medium, fontSize=11, leading=11)
-    s_table_large_center = ParagraphStyle(name="s_table_large", parent=s_table_large, alignment=TA_CENTER)
+    s_table_large_center = ParagraphStyle(name="s_table_large", parent=s_table_large, alignment=TA_CENTER)  # noqa: F841
     s_table_center = ParagraphStyle(
         name="s_table_center",
         parent=s_table_base,
@@ -330,7 +331,7 @@ def generate_report(context):
     # Price Timeseries Chart
     elements.append(
         get_timeseries_chart(
-            data=[list(zip(prices.index, prices.net_value))],
+            data=[list(zip(prices.index, prices.net_value, strict=False))],
             width=CONTENT_WIDTH_PAGE1_LEFT - CONTENT_OFFSET,
             height=4.34 * cm,
             color=c_product,
@@ -351,7 +352,7 @@ def generate_report(context):
                 "<strong>Top 3 Contributors</strong>",
                 "<strong>Bottom 3 Contributors</strong>",
             ],
-            data=list(zip(top_3_holdings, top_3_contributors, bottom_3_contributors)),
+            data=list(zip(top_3_holdings, top_3_contributors, bottom_3_contributors, strict=False)),
             width=CONTENT_WIDTH_PAGE1_LEFT,
             header_row_height=0.85 * cm,
             data_row_height=0.39 * cm,
@@ -553,7 +554,7 @@ def generate_report(context):
 
         data = list()
         categories = list()
-        for index, row in enumerate(df.itertuples()):
+        for row in df.itertuples():
             data.append(row.weighting * 100)
             categories.append(f"{row.aggregated_title} ({row.weighting*100:.1f}%)")
 
